
def add_one(number):
    '''
        加一
    '''
    return number + 1

def zhishu(n):
    '''
        判断质数
    '''
    for x in range(2,n-1):
        if n%x == 0:
            return False
    return True

def oushu(n):
    '''
        判断偶数
    '''
    if n%2 == 0:
        return True
    else:
        return False
def pingfang(n):
    '''
        计算平方
    '''
    return n*n
def jitutonglong(n,m):
    '''
        解鸡兔同笼问题
    '''
    flag = [0,0]
    for x in range(n):
        if 2*x+4*(n-x) == m:
            flag[0] = x
            flag[1] = n-x
            return flag
    return "不可能出现的情况"